@@ -15,6 +15,9 @@ def ShowLogFFT( data, fs = 1, MaxFftLength = 10000, bPlotRelative = True):
     import numpy
     limiterlen = min(MaxFftLength,len(data))
 
+    plt.ion()
+    plt.show()
+
     if bPlotRelative:
         mag = 20*numpy.log10(numpy.abs(numpy.fft.fftshift(numpy.fft.fft(data[:limiterlen]))))
         # normalize to mean
@@ -31,7 +34,9 @@ def ShowLogFFT( data, fs = 1, MaxFftLength = 10000, bPlotRelative = True):
         plt.ylabel( 'relative power / dB')
     else:
         plt.ylabel( 'power / dBm')
-    plt.show()
+    plt.draw()
+    plt.pause(.001)
+    
 
 
 if __name__ == "__main__":
